aboutsummaryrefslogtreecommitdiff
path: root/src/Startup.c
diff options
context:
space:
mode:
authortradke <tradke@94b1c47f-dcfd-45ef-a468-0854c0e9e350>2002-05-06 09:11:42 +0000
committertradke <tradke@94b1c47f-dcfd-45ef-a468-0854c0e9e350>2002-05-06 09:11:42 +0000
commit84df6a1831d14dcd7a80b7c65758919a78732df0 (patch)
treeb66b71102d27bfaf0b90d5dd5918292041b092d0 /src/Startup.c
parent76d4e575a9901080e16d0558e9d65f7a1ec8fe22 (diff)
Parameter names changes as announced in today's mail to users@cactuscode.org.
You must also update thorn IOUtil now. git-svn-id: http://svn.cactuscode.org/arrangements/CactusBase/IOASCII/trunk@113 94b1c47f-dcfd-45ef-a468-0854c0e9e350
Diffstat (limited to 'src/Startup.c')
-rw-r--r--src/Startup.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/Startup.c b/src/Startup.c
index eb24978..bee548b 100644
--- a/src/Startup.c
+++ b/src/Startup.c
@@ -26,12 +26,12 @@ CCTK_FILEVERSION(CactusBase_IOASCII_Startup_c)
/********************************************************************
******************** Macro Definitions ************************
********************************************************************/
-#define CREATE_OUTDIR(dir) \
+#define CREATE_OUTDIR(method, dir) \
{ \
/* check whether "dir" was set; if not default to "IO::outdir" */ \
if (*dir == 0) \
{ \
- dir = outdir; \
+ dir = out_dir; \
} \
\
/* omit the directory name if it's the current working dir */ \
@@ -50,13 +50,13 @@ CCTK_FILEVERSION(CactusBase_IOASCII_Startup_c)
if (i < 0) \
{ \
CCTK_VWarn (1, __LINE__, __FILE__, CCTK_THORNSTRING, \
- "IOASCII_SetupGH: Problem creating IOASCII output " \
- "directory '%s'", myGH->dir); \
+ "IOASCII_SetupGH: Problem creating %s output " \
+ "directory '%s'", method, myGH->dir); \
} \
- else if (i >= 0 && CCTK_Equals (newverbose, "full")) \
+ else if (i >= 0 && CCTK_Equals (verbose, "full")) \
{ \
- CCTK_VInfo (CCTK_THORNSTRING, "IOASCII_1D: Output to directory " \
- "'%s'", myGH->dir); \
+ CCTK_VInfo (CCTK_THORNSTRING, "%s: Output to directory '%s'", \
+ method, myGH->dir); \
} \
}
@@ -168,7 +168,7 @@ static void *IOASCII_SetupGH (tFleshConfig *config, int conv_level, cGH *GH)
CCTK_RegisterIOMethodTimeToOutput (i, IOASCII_TimeFor3D);
CCTK_RegisterIOMethodTriggerOutput (i, IOASCII_TriggerOutput3D);
- if (! CCTK_Equals (newverbose, "none"))
+ if (! CCTK_Equals (verbose, "none"))
{
CCTK_INFO ("I/O Method 'IOASCII_1D' registered");
CCTK_INFO ("IOASCII_1D: Output of 1D lines of grid functions/arrays "
@@ -207,9 +207,9 @@ static void *IOASCII_SetupGH (tFleshConfig *config, int conv_level, cGH *GH)
myGH->fileList_3D = NULL;
/* make sure all output directories exist */
- CREATE_OUTDIR (outdir1D);
- CREATE_OUTDIR (outdir2D);
- CREATE_OUTDIR (outdir3D);
+ CREATE_OUTDIR ("IOASCII_1D", out1D_dir);
+ CREATE_OUTDIR ("IOASCII_2D", out2D_dir);
+ CREATE_OUTDIR ("IOASCII_3D", out3D_dir);
return (myGH);
}
@@ -26,12 +26,12 @@ CCTK_FILEVERSION(CactusBase_IOASCII_Startup_c)
{ \
- /* check whether "dir" was set; if not default to "IO::outdir" */ \
+ /* check whether "dir" was set; if not default to "IO::out_dir" */ \
if (*dir == 0) \
{ \